#!/usr/bin/env python

from distutils.core import setup

setup(name='gurlshortner',
      version='0.1.2',
      description='URL shortner using Google APIs',
      author='Aditya Patawari',
      author_email='aditya@adityapatawari.com',
      url='https://github.com/adimania/gurlshortner',
      py_modules=['gurlshortner'],
     )
